pysqueezecenter.player.Player — PySqueezeCenter v0.1 documentation

### Navigation

- index
- previous |
- PySqueezeCenter v0.1 documentation »

# `pysqueezecenter.player.Player`

class `pysqueezecenter.player.` `Player`(sc, index=None)
  `bass`
    Get Player Bass
  `bass_down`(amount=5)
    Decrease Player Bass
  `bass_up`(amount=5)
    Increase Player Bass
  `can_power_off`
    Player Can Power Off?
  `display_type`
    Get Player Display Type String
  `forward`(seconds=10)
    Seek Player Forward
  `get_bass`()
    Get Player Bass
  `get_display_type`()
    Get Player Display Type String
  `get_id`()
    Get Player ID
  `get_ip_address`()
    Get Player IP Address
  `get_ir_state`()
    Get Player Infrared State
  `get_mode`()
    Get Player Mode
  `get_model`()
    Get Player Model String
  `get_muting`()
    Get Player Muting Status
  `get_name`()
    Get Player Name
  `get_pitch`()
    Get Player Pitch
  `get_power_state`()
    Get Player Power State
  `get_pref_value`(name, namespace=None)
    Get Player Preference Value
  `get_rate`()
    Get Player Rate
  `get_time_elapsed`()
    Get Player Time Elapsed
  `get_time_remaining`()
    Get Player Time Remaining
  `get_track_album`()
    Get Players Current Track Album
  `get_track_artist`()
    Get Players Current Track Artist
  `get_track_current_title`()
    Get Players Current Track Current Title
  `get_track_duration`()
    Get Players Current Track Duration
  `get_track_genre`()
    Get Players Current Track Genre
  `get_track_path`()
    Get Players Current Track Path
  `get_track_remote`()
    Is Players Current Track Remotely Hosted?
  `get_track_title`()
    Get Players Current Track Title
  `get_treble`()
    Get Player Treble
  `get_uuid`()
    Get Player UUID
  `get_volume`()
    Get Player Volume
  `get_wifi_signal_strength`()
    Get Player WiFi Signal Strength
  `has_permission`(request_terms)
    Check Player User Permissions
  `id`
    Get Player ID
  `ip_address`
    Get Player IP Address
  `ir_button`(button)
    Simulate IR Button Press
  `ir_state`
    Get Player Infrared State
  `is_connected`
    Player Connected?
  `is_player`
    Real Player?
  `mode`
    Get Player Mode
  `model`
    Get Player Model String
  `mute`()
    Mute Player
  `muting`
    Get Player Muting Status
  `name`
    Get Player Name
  `next`()
    Next Track
  `pause`()
    Pause On
  `pitch`
    Get Player Pitch
  `pitch_down`(amount=5)
    Decrease Player Pitch
  `pitch_up`(amount=5)
    Increase Player Pitch
  `play`()
    Play
  `playlist_delete`(item)
    Delete Item From Playlist By Name
  `playlist_erase`(index)
    Erase Item From Playlist
  `playlist_insert`(item)
    Insert Item Into Playlist (After Current Track)
  `playlist_move`(from_index, to_index)
    Move Item In Playlist
  `playlist_play`(item)
    Add Item To Playlist
  `power_state`
    Get Player Power State
  `prev`()
    Previous Track
  `rate`
    Get Player Rate
  `rate_down`(amount=1)
    Decrease Player Rate
  `rate_up`(amount=1)
    Increase Player Rate
  `rewind`(seconds=10)
    Seek Player Backwards
  `seek_to`(seconds)
    Seek Player
  `set_bass`(bass)
    Set Player Bass
  `set_ir_state`(state)
    Set Player Power State
  `set_muting`(state)
    Set Player Muting Status
  `set_name`(name)
    Set Player Name
  `set_pitch`(pitch)
    Set Player Pitch
  `set_power_state`(state)
    Set Player Power State
  `set_pref_value`(name, value, namespace=None)
    Set Player Preference Value
  `set_rate`(rate)
    Set Player Rate
  `set_treble`(treble)
    Set Player Treble
  `set_volume`(volume)
    Set Player Volume
  `show`(line1='', line2='', duration=3, brightness=4, font='standard', centered=False)
    Displays text on Player display
  `stop`()
    Stop
  `time_elapsed`
    Get Player Time Elapsed
  `time_remaining`
    Get Player Time Remaining
  `toggle`()
    Play/Pause Toggle
  `track_artist`
    Get Players Current Track Artist
  `track_current_title`
    Get Players Current Track Current Title
  `track_duration`
    Get Players Current Track Duration
  `track_genre`
    Get Players Current Track Genre
  `track_path`
    Get Players Current Track Path
  `track_remote`
    Is Players Current Track Remotely Hosted?
  `track_title`
    Get Players Current Track Title
  `treble`
    Get Player Treble
  `treble_down`(amount=5)
    Decrease Player Treble
  `treble_up`(amount=5)
    Increase Player Treble
  `unmute`()
    Unmute Player
  `unpause`()
    Pause Off
  `uuid`
    Get Player UUID
  `volume`
    Get Player Volume
  `volume_down`(amount=5)
    Decrease Player Volume
  `volume_up`(amount=5)
    Increase Player Volume
  `wifi_signal_strength`
    Get Player WiFi Signal Strength

### Navigation

- index
- previous |
- PySqueezeCenter v0.1 documentation »